#[repr(u8)]pub enum Pincfg {
SIN_IN_SOUT_OUT = 0,
SIN_BOTH_IN_OUT = 1,
SOUT_BOTH_IN_OUT = 2,
SOUT_IN_SIN_OUT = 3,
}Variants
SIN_IN_SOUT_OUT = 0
SIN is used for input data; SOUT is used for output data
SIN_BOTH_IN_OUT = 1
SIN is used for both input and output data; only half-duplex serial transfers are supported
SOUT_BOTH_IN_OUT = 2
SOUT is used for both input and output data; only half-duplex serial transfers are supported
SOUT_IN_SIN_OUT = 3
SOUT is used for input data; SIN is used for output data
Implementations